bind

package
v0.0.0-...-2f2fe40 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 21, 2014 License: BSD-3-Clause Imports: 10 Imported by: 0

Documentation

Overview

Package bind implements a code generator for gobind.

See the documentation on the gobind command for usage details.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenGo

func GenGo(w io.Writer, fset *token.FileSet, pkg *types.Package) error

GenGo generates a Go stub to support foreign language APIs.

func GenJava

func GenJava(w io.Writer, fset *token.FileSet, pkg *types.Package) error

GenJava generates a Java API from a Go package.

Types

type ErrorList

type ErrorList []error

func (ErrorList) Error

func (list ErrorList) Error() string

Directories

Path Synopsis
java
testpkg
Package testpkg contains bound functions for testing the cgo-JNI interface.
Package testpkg contains bound functions for testing the cgo-JNI interface.
testpkg/go_testpkg
Package go_testpkg is an autogenerated binder stub for package testpkg.
Package go_testpkg is an autogenerated binder stub for package testpkg.
Package seq implements the machine-dependent seq serialization format.
Package seq implements the machine-dependent seq serialization format.

Jump to