Documentation
¶
Overview ¶
Package seq implements the machine-dependent seq serialization format.
Implementations of Transact and FinalizeRef are provided by a specific foreign language binding package, e.g. go.mobile/bind/java.
Designed only for use by the code generated by gobind. Don't try to use this directly.
Index ¶
- Variables
- func Delete(num int32)
- func Register(descriptor string, code int, fn Func)
- type Buffer
- func (b *Buffer) ReadFloat32() float32
- func (b *Buffer) ReadFloat64() float64
- func (b *Buffer) ReadInt() int
- func (b *Buffer) ReadInt32() int32
- func (b *Buffer) ReadInt64() int64
- func (b *Buffer) ReadRef() *Ref
- func (b *Buffer) ReadUTF16() string
- func (b *Buffer) String() string
- func (b *Buffer) WriteFloat32(v float32)
- func (b *Buffer) WriteFloat64(v float64)
- func (b *Buffer) WriteGoRef(obj interface{})
- func (b *Buffer) WriteInt(v int)
- func (b *Buffer) WriteInt32(v int32)
- func (b *Buffer) WriteInt64(v int64)
- func (b *Buffer) WriteRef(ref *Ref)
- func (b *Buffer) WriteUTF16(s string)
- type Func
- type Ref
Constants ¶
This section is empty.
Variables ¶
var FinalizeRef func(ref *Ref)
FinalizeRef is the finalizer used on foreign objects.
var Registry = make(map[string]map[int]Func)
Registry holds functions callable from gobind generated bindings. Functions are keyed by descriptor and function code.
var Transact func(ref *Ref, code int, in *Buffer) (out *Buffer)
Transact calls a method on a foreign object instance. It blocks until the call is complete.
Functions ¶
Types ¶
type Buffer ¶
Buffer is a set of arguments or return values from a function call across the language boundary. Encoding is machine-dependent.
func (*Buffer) ReadFloat32 ¶
func (*Buffer) ReadFloat64 ¶
func (*Buffer) WriteFloat32 ¶
func (*Buffer) WriteFloat64 ¶
func (*Buffer) WriteGoRef ¶
func (b *Buffer) WriteGoRef(obj interface{})